# OPS03: How does your organizational culture support your business outcomes?

## References

- [AWS OPS03](https://docs.aws.amazon.com/wellarchitected/latest/framework/ops-03.html)
- [DORA State of DevOps 2024](https://dora.dev/research/2024/dora-report/)
- [Google SRE - Postmortems](https://sre.google/sre-book/postmortem-culture/)

## Date

2025-11-27

## Focus Area

Organization

## Tổng quan

OPS03 tập trung vào văn hóa tổ chức hỗ trợ business outcomes. Bao gồm psychological safety, experimentation, và continuous learning.

## DORA Metrics (2024-2025)

> **Update 2024:** DORA sử dụng **7 team archetypes** thay vì 4-tier model.

| Metric | Elite | High | Medium | Low |
|--------|-------|------|--------|-----|
| **Deployment Frequency** | Multiple/day | Daily-weekly | Weekly-monthly | Monthly+ |
| **Lead Time** | <1 day | 1 day-1 week | 1-6 months | 6+ months |
| **Change Failure Rate** | <5% | 10-15% | 16-30% | >45% |
| **MTTR** | <1 hour | <1 day | 1 day-1 week | 1+ week |

## Best Practices

| BP | Name | Description |
|----|------|-------------|
| [OPS03-BP01](OPS03-BP01-Executive-Sponsorship.md) | Executive sponsorship | Leadership cam kết cho transformation |
| [OPS03-BP02](OPS03-BP02-Team-Members-Empowered.md) | Team members empowered | Team được trao quyền |
| [OPS03-BP03](OPS03-BP03-Escalation-Encouraged.md) | Escalation encouraged | Khuyến khích escalation |
| [OPS03-BP04](OPS03-BP04-Communications-Clear.md) | Communications clear | Giao tiếp rõ ràng |
| [OPS03-BP05](OPS03-BP05-Experimentation-Encouraged.md) | Experimentation encouraged | Khuyến khích thử nghiệm |
| [OPS03-BP06](OPS03-BP06-Skill-Development.md) | Skill development | Hỗ trợ phát triển kỹ năng |

## Checklist

- [ ] Psychological safety promoted
- [ ] Blameless postmortem process established
- [ ] Learning time allocated
- [ ] Knowledge sharing mechanisms in place
- [ ] DORA metrics tracked
- [ ] Cross-team collaboration encouraged
